@@ -1,13 +1,11 @@
 var class_ogre_1_1_embedded_zip_archive_factory =
 [
-    [ "DecryptEmbeddedZipFileFunc", "class_ogre_1_1_embedded_zip_archive_factory.html#a9ef899ac1ebf7ab54f115c8ced9ff433", null ],
+    [ "DecryptEmbeddedZipFileFunc", "class_ogre_1_1_embedded_zip_archive_factory.html#a1ff410fc9109fd10d687aeaa48c13cf0", null ],
     [ "EmbeddedZipArchiveFactory", "class_ogre_1_1_embedded_zip_archive_factory.html#a5af58e0e7685eddfd25f2c241ccc1a5c", null ],
     [ "~EmbeddedZipArchiveFactory", "class_ogre_1_1_embedded_zip_archive_factory.html#ab2ec7ad5b0989ef7088dc77ef9b7351f", null ],
     [ "getType", "class_ogre_1_1_embedded_zip_archive_factory.html#a6537173ebc5bc73cd9043b2f12922535", null ],
     [ "createInstance", "class_ogre_1_1_embedded_zip_archive_factory.html#a77ab8163f8e6638d14986275eeb14800", null ],
     [ "destroyInstance", "class_ogre_1_1_embedded_zip_archive_factory.html#a68b5b3f50a4cbd995c5e3b968782ec3e", null ],
     [ "addEmbbeddedFile", "class_ogre_1_1_embedded_zip_archive_factory.html#aa2c388afbb8ff7dfb301bbe95495ed6b", null ],
-    [ "removeEmbbeddedFile", "class_ogre_1_1_embedded_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478", null ],
-    [ "createInstance", "class_ogre_1_1_embedded_zip_archive_factory.html#a51a3c68688eca8878bdecdc44929ee1a", null ],
-    [ "createInstance", "class_ogre_1_1_embedded_zip_archive_factory.html#a08586d13d121b5639de009b73ec28e82", null ]
+    [ "removeEmbbeddedFile", "class_ogre_1_1_embedded_zip_archive_factory.html#a2ce05ec837366adb88a8b9f573085478", null ]
 ];
\ No newline at end of file
