@@ -1,10 +1,10 @@
 var class_ogre_1_1_pass =
 [
     [ "HashFunc", "struct_ogre_1_1_pass_1_1_hash_func.html", "struct_ogre_1_1_pass_1_1_hash_func" ],
-    [ "TextureUnitStates", "class_ogre_1_1_pass.html#a1054ecda87f96dad530ec49099379755", null ],
-    [ "PassSet", "class_ogre_1_1_pass.html#aaedba8526ffd478f5d731507c4779caf", null ],
-    [ "TextureUnitStateIterator", "class_ogre_1_1_pass.html#ac7bc2b00e42ad2699a1e2a1de340d3b4", null ],
-    [ "ConstTextureUnitStateIterator", "class_ogre_1_1_pass.html#a98b42a4f4304f3f2d08fb9394cbefe83", null ],
+    [ "TextureUnitStates", "class_ogre_1_1_pass.html#a97e5a74847664d60fb741eca605d9960", null ],
+    [ "PassSet", "class_ogre_1_1_pass.html#a9a397a3383ca34ff91e67fe4126ca1a5", null ],
+    [ "TextureUnitStateIterator", "class_ogre_1_1_pass.html#a8ac6972d87fade69312d80d8c7049d59", null ],
+    [ "ConstTextureUnitStateIterator", "class_ogre_1_1_pass.html#ac95db75cb036fe01bc7e9a37934c6ff8", null ],
     [ "BuiltinHashFunction", "class_ogre_1_1_pass.html#a1d30a3c04994e1bd0e1de8cb343341a4", [
       [ "MIN_TEXTURE_CHANGE", "class_ogre_1_1_pass.html#a1d30a3c04994e1bd0e1de8cb343341a4aab72a14d25f118c99dd6e9d40953ca46", null ],
       [ "MIN_GPU_PROGRAM_CHANGE", "class_ogre_1_1_pass.html#a1d30a3c04994e1bd0e1de8cb343341a4a281f843d23df9554e590a19d1a3987e3", null ]
@@ -200,8 +200,6 @@ var class_ogre_1_1_pass =
     [ "_recalculateHash", "class_ogre_1_1_pass.html#a367a1affcb2e26d61a5b5e3594b0ce6a", null ],
     [ "_notifyNeedsRecompile", "class_ogre_1_1_pass.html#a6d9af04b4a643df1d81cc0443ca34ab2", null ],
     [ "_updateAutoParams", "class_ogre_1_1_pass.html#ad17196c5383815e1af157fc9617c474b", null ],
-    [ "setNormaliseNormals", "class_ogre_1_1_pass.html#ad00b9d37cf0d5d7af26d23a2a48f5541", null ],
-    [ "getNormaliseNormals", "class_ogre_1_1_pass.html#a858b9c564570fd84e19c77a9b84da557", null ],
     [ "getDirtyHashList", "class_ogre_1_1_pass.html#a8db1ef396830a458b80e26cb64967a90", null ],
     [ "getPassGraveyard", "class_ogre_1_1_pass.html#ac5f4c80e53eb3776483b3414893c4235", null ],
     [ "clearDirtyHashList", "class_ogre_1_1_pass.html#af1992ef39ef97e0b48e878c9aaa2badd", null ],
