@@ -6,13 +6,12 @@ var class_ogre_1_1_scene_manager =
     [ "SkyBoxGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_box_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_box_gen_parameters" ],
     [ "SkyDomeGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_dome_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_dome_gen_parameters" ],
     [ "SkyPlaneGenParameters", "struct_ogre_1_1_scene_manager_1_1_sky_plane_gen_parameters.html", "struct_ogre_1_1_scene_manager_1_1_sky_plane_gen_parameters" ],
-    [ "CameraList", "class_ogre_1_1_scene_manager.html#a361c61a0f17ac50c8fd49bc0dd3ff622", null ],
-    [ "AnimationList", "class_ogre_1_1_scene_manager.html#a260738557c9a32aed8d5ca14c28d300f", null ],
-    [ "MovableObjectMap", "class_ogre_1_1_scene_manager.html#a317d0ca0b29d739ed54b4422f850b629", null ],
-    [ "StaticGeometryMap", "class_ogre_1_1_scene_manager.html#a0cd89dcbd8d830a2a3c03dac27f42c44", null ],
-    [ "CameraIterator", "class_ogre_1_1_scene_manager.html#a22fcb8a9ddb7efe79d053a975a685111", null ],
-    [ "AnimationIterator", "class_ogre_1_1_scene_manager.html#a3a720414f68274bb9c5026911e27135d", null ],
-    [ "MovableObjectIterator", "class_ogre_1_1_scene_manager.html#a4249682ae2a69255ed225383d930aec1", null ],
+    [ "CameraList", "class_ogre_1_1_scene_manager.html#a38847db2463282eac2728364b0b1666e", null ],
+    [ "MovableObjectMap", "class_ogre_1_1_scene_manager.html#a6956cac004a5395d38dc985e0b25c6b6", null ],
+    [ "StaticGeometryMap", "class_ogre_1_1_scene_manager.html#ab4c430408f3af789d26db1fec23923e8", null ],
+    [ "CameraIterator", "class_ogre_1_1_scene_manager.html#a447537fadb1f59655896fda8b4b1bb3b", null ],
+    [ "AnimationIterator", "class_ogre_1_1_scene_manager.html#a7b45ae03efd2ee5aa81a2680c81559b2", null ],
+    [ "MovableObjectIterator", "class_ogre_1_1_scene_manager.html#afc2d3748c16a354c07e01a9006171afd", null ],
     [ "QueryTypeMask", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638a", [
       [ "WORLD_GEOMETRY_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aabf31f2e39287202aaf433b4f4eca2ba9", null ],
       [ "ENTITY_TYPE_MASK", "class_ogre_1_1_scene_manager.html#a6d604937ee8d07e24f99ba5cdf64638aa7b1c9dfb3ee3bf4224e445b9417193e0", null ],
@@ -35,6 +34,8 @@ var class_ogre_1_1_scene_manager =
     [ "~SceneManager", "class_ogre_1_1_scene_manager.html#a6c8b9108b44339a321bc69b25a0c0a1a", null ],
     [ "_pauseRendering", "class_ogre_1_1_scene_manager.html#a5c9816798bda78389efc4f071051c739", null ],
     [ "_resumeRendering", "class_ogre_1_1_scene_manager.html#a794e03ea25dd798346414c1dba31337d", null ],
+    [ "usePerRenderableLights", "class_ogre_1_1_scene_manager.html#abea7f1022bf24e920d9e0771314bda9c", null ],
+    [ "hasPerRenderableLights", "class_ogre_1_1_scene_manager.html#a053df07afa2037d378450e2063b45560", null ],
     [ "OGRE_MUTEX", "class_ogre_1_1_scene_manager.html#a9b10b7fef2893e75acc083415df70446", null ],
     [ "getName", "class_ogre_1_1_scene_manager.html#a8d29d1e2d954090ce2fba768b7f30c02", null ],
     [ "getTypeName", "class_ogre_1_1_scene_manager.html#a2f139de7c96a237754f075dbca80670e", null ],
@@ -140,24 +141,27 @@ var class_ogre_1_1_scene_manager =
     [ "_setDestinationRenderSystem", "class_ogre_1_1_scene_manager.html#ae87a0ee032dd09c82fa13e503711cc2b", null ],
     [ "_releaseManualHardwareResources", "class_ogre_1_1_scene_manager.html#a6a518d9bb5e39500df870f538be7a939", null ],
     [ "_restoreManualHardwareResources", "class_ogre_1_1_scene_manager.html#ad72c0a636bfdb7a891de44073ad26835", null ],
+    [ "setSkyRenderingEnabled", "class_ogre_1_1_scene_manager.html#a851077fcf56225e174e0f0a52230061c", null ],
+    [ "isSkyRenderingEnabled", "class_ogre_1_1_scene_manager.html#abf27eb2afe2ce63e21f474aaad7dac9b", null ],
+    [ "getSkyNode", "class_ogre_1_1_scene_manager.html#a3385006ec7d87a733a8e7ca66491bc21", null ],
     [ "setSkyPlane", "class_ogre_1_1_scene_manager.html#aebb644c23f059b8bfa3702356d19c6be", null ],
     [ "_setSkyPlane", "class_ogre_1_1_scene_manager.html#a23a02fc191d8dacf508515c0116b45b1", null ],
     [ "setSkyPlaneEnabled", "class_ogre_1_1_scene_manager.html#a5e629af63f5f273a69aa9cf1e9bbceb7", null ],
     [ "isSkyPlaneEnabled", "class_ogre_1_1_scene_manager.html#a19e58a6ea76b7bb775358fcf01b5741a", null ],
     [ "getSkyPlaneNode", "class_ogre_1_1_scene_manager.html#a7be351186ec2cc070e74561ba7e4175f", null ],
-    [ "getSkyPlaneGenParameters", "class_ogre_1_1_scene_manager.html#ab3c06e47b94c56dfb733d3e94b61bf89", null ],
+    [ "getSkyPlaneGenParameters", "class_ogre_1_1_scene_manager.html#a33624066a0da8b548f283f983dd19575", null ],
     [ "setSkyBox", "class_ogre_1_1_scene_manager.html#a370c23fff9cc351b150632c707a46700", null ],
     [ "_setSkyBox", "class_ogre_1_1_scene_manager.html#abd6e42cd9332673bddd79f31ef423c1e", null ],
     [ "setSkyBoxEnabled", "class_ogre_1_1_scene_manager.html#a79cd2c00addb8bb51943e0080d92c633", null ],
     [ "isSkyBoxEnabled", "class_ogre_1_1_scene_manager.html#a100bac7be3a9303d09918d55199f7a5f", null ],
     [ "getSkyBoxNode", "class_ogre_1_1_scene_manager.html#ae68e31e10d39aab32b8ab96455d8adfa", null ],
-    [ "getSkyBoxGenParameters", "class_ogre_1_1_scene_manager.html#a19356ff8380050c477dca534c0b72881", null ],
+    [ "getSkyBoxGenParameters", "class_ogre_1_1_scene_manager.html#a6ab80081d2ef6ccebc6bb0a39452bb01", null ],
     [ "setSkyDome", "class_ogre_1_1_scene_manager.html#ac1c49622909068c8c7551d5a896ada43", null ],
     [ "_setSkyDome", "class_ogre_1_1_scene_manager.html#ab2bd35627468a27a8e52a30cc364cc82", null ],
     [ "setSkyDomeEnabled", "class_ogre_1_1_scene_manager.html#a115c5ba0e3bb0ba7cc52f8f301c0e220", null ],
     [ "isSkyDomeEnabled", "class_ogre_1_1_scene_manager.html#abcee0ad945d2d8cfd43097ed378db8d8", null ],
     [ "getSkyDomeNode", "class_ogre_1_1_scene_manager.html#a088afab61603ceb636d0d428ef73d9ca", null ],
-    [ "getSkyDomeGenParameters", "class_ogre_1_1_scene_manager.html#abf45ec8e9f0d505f6592c45b36d949e1", null ],
+    [ "getSkyDomeGenParameters", "class_ogre_1_1_scene_manager.html#a45887375e05f0a6473c6265913ab9dae", null ],
     [ "setFog", "class_ogre_1_1_scene_manager.html#a4222a0689cb56011c11faa9976192f11", null ],
     [ "getFogMode", "class_ogre_1_1_scene_manager.html#aeaff7cf546903bc22c4113c1ae4a7ee4", null ],
     [ "getFogColour", "class_ogre_1_1_scene_manager.html#ae8ddefa5590c1209169e53fb6c02f29e", null ],
@@ -172,9 +176,12 @@ var class_ogre_1_1_scene_manager =
     [ "destroyBillboardSet", "class_ogre_1_1_scene_manager.html#a372aa23ce7f0d6c29b32e718f51b595c", null ],
     [ "destroyAllBillboardSets", "class_ogre_1_1_scene_manager.html#aa316e7d1a4d80e75940246ccb260bcca", null ],
     [ "_applySceneAnimations", "class_ogre_1_1_scene_manager.html#ab8ebc8d2fdc6798152ac6a31282de210", null ],
-    [ "createAnimation", "class_ogre_1_1_scene_manager.html#a20ad822590a14075d7858345c934655a", null ],
-    [ "getAnimation", "class_ogre_1_1_scene_manager.html#aec3eb79e5b2453c9d7470a4ad98db9b3", null ],
-    [ "hasAnimation", "class_ogre_1_1_scene_manager.html#a4257eae21878329ae84446332443366a", null ],
+    [ "createAnimation", "class_ogre_1_1_scene_manager.html#aad530a7588b2544eba74370c041dfbe5", null ],
+    [ "getAnimation", "class_ogre_1_1_scene_manager.html#a00b1fef15425cbcaede60137f78f2e4d", null ],
+    [ "hasAnimation", "class_ogre_1_1_scene_manager.html#a0f2337636c29427cdd711b51aa29eb71", null ],
+    [ "getNumAnimations", "class_ogre_1_1_scene_manager.html#afaba8c61edcedd1214b8b25e0ad178e4", null ],
+    [ "getAnimation", "class_ogre_1_1_scene_manager.html#a7b33443d4ec80ecba17eba8dab4491a2", null ],
+    [ "removeAnimation", "class_ogre_1_1_scene_manager.html#a87bb32dcfef86f5d04495ead956ad7e4", null ],
     [ "destroyAnimation", "class_ogre_1_1_scene_manager.html#a863ba56ae571446bb0807aa7e7204d1d", null ],
     [ "destroyAllAnimations", "class_ogre_1_1_scene_manager.html#aac4d1620c2d2d9ab5c78a3730eabc180", null ],
     [ "createAnimationState", "class_ogre_1_1_scene_manager.html#a53d1cf1fd4f032a10b4672f288322ddf", null ],
