@@ -2,7 +2,10 @@ var group___b_s_p_scene_manager =
 [
     [ "Ogre::BspIntersectionSceneQuery", "class_ogre_1_1_bsp_intersection_scene_query.html", [
       [ "BspIntersectionSceneQuery", "class_ogre_1_1_bsp_intersection_scene_query.html#a41f6ea17202f479bff9081bfbd69b758", null ],
-      [ "execute", "class_ogre_1_1_bsp_intersection_scene_query.html#aeb15094d92857e8646f716432a152ca8", null ]
+      [ "execute", "class_ogre_1_1_bsp_intersection_scene_query.html#a3dbf1d10649286de4ead6b136d4f3eaa", null ],
+      [ "setWorldFragmentType", "class_ogre_1_1_bsp_intersection_scene_query.html#a1f739991d9f5c0fe7d59ac431708f318", null ],
+      [ "getWorldFragmentType", "class_ogre_1_1_bsp_intersection_scene_query.html#a4f51de3690a1a8ff23a6a45b2c35861c", null ],
+      [ "getSupportedWorldFragmentTypes", "class_ogre_1_1_bsp_intersection_scene_query.html#aae0ab3526e9bfbf9ec85f5b6a4d99228", null ]
     ] ],
     [ "Ogre::BspLevel", "class_ogre_1_1_bsp_level.html", [
       [ "BspLevel", "class_ogre_1_1_bsp_level.html#a058020fea4785609e67b628c479e35e2", null ],
@@ -32,8 +35,8 @@ var group___b_s_p_scene_manager =
         [ "planes", "struct_ogre_1_1_bsp_node_1_1_brush.html#a62726d014908dee79b47d4048184afaa", null ],
         [ "fragment", "struct_ogre_1_1_bsp_node_1_1_brush.html#a1e6740b48713e3cc1fc3bdb62b9a6e64", null ]
       ] ],
-      [ "IntersectingObjectSet", "class_ogre_1_1_bsp_node.html#ab84d20216766664f21528d05874b85fd", null ],
-      [ "NodeBrushList", "class_ogre_1_1_bsp_node.html#ae3d22295df76fd693f56386db2ccaa15", null ],
+      [ "IntersectingObjectSet", "class_ogre_1_1_bsp_node.html#acc9262dbc255f7b9d00ed61a30166a36", null ],
+      [ "NodeBrushList", "class_ogre_1_1_bsp_node.html#a9057cc500de27abe8f6494f8dd369aac", null ],
       [ "BspNode", "class_ogre_1_1_bsp_node.html#a39b74504f7252462d27f69bbeef5dc99", null ],
       [ "BspNode", "class_ogre_1_1_bsp_node.html#a10395588ed29a1d34e3b028643dd2d77", null ],
       [ "~BspNode", "class_ogre_1_1_bsp_node.html#a74871a4318ee6f0bfdf068a988bc2496", null ],
@@ -58,41 +61,43 @@ var group___b_s_p_scene_manager =
     [ "Ogre::BspRaySceneQuery", "class_ogre_1_1_bsp_ray_scene_query.html", [
       [ "BspRaySceneQuery", "class_ogre_1_1_bsp_ray_scene_query.html#ae28099aef7f983a042efde7e298295b9", null ],
       [ "~BspRaySceneQuery", "class_ogre_1_1_bsp_ray_scene_query.html#af688336da3971472963b32e52b17d251", null ],
-      [ "execute", "class_ogre_1_1_bsp_ray_scene_query.html#a0c98549a0b1e7db7d54c6bbfc4f46d8f", null ]
+      [ "setWorldFragmentType", "class_ogre_1_1_bsp_ray_scene_query.html#ae7d9dcfa961dcaf756c5ac2b278413eb", null ],
+      [ "getWorldFragmentType", "class_ogre_1_1_bsp_ray_scene_query.html#a0b402c03852f58373e2f8224242e1f4d", null ],
+      [ "getSupportedWorldFragmentTypes", "class_ogre_1_1_bsp_ray_scene_query.html#a5887059ed82ee59e0e5f0ae149b244d8", null ],
+      [ "execute", "class_ogre_1_1_bsp_ray_scene_query.html#a0a7e638608a44ba0b50998b84029d324", null ]
     ] ],
     [ "Ogre::BspSceneManager", "class_ogre_1_1_bsp_scene_manager.html", [
       [ "BspSceneManager", "class_ogre_1_1_bsp_scene_manager.html#ab3e178ca87404a0687e2523e756ff5fd", null ],
       [ "~BspSceneManager", "class_ogre_1_1_bsp_scene_manager.html#aa872f5ea2bedbeb7dd9cf1b25a110c35", null ],
-      [ "getTypeName", "class_ogre_1_1_bsp_scene_manager.html#a26625c537529cba039d4e30424ac6cf2", null ],
-      [ "setWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a4444e8e94c01206790db4bfad8c487ea", null ],
-      [ "estimateWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a12cfc049e1d6c343f9ecd6a4546265b4", null ],
-      [ "setWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a91c52dc16409d813d917981aeaf5359b", null ],
-      [ "estimateWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a9746fa406d8edbf8a80f1afcf009584b", null ],
+      [ "getTypeName", "class_ogre_1_1_bsp_scene_manager.html#aefb30f708df66332b50fa83d241b2305", null ],
+      [ "setWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a14115743f2fd57a125e6e7fa485e622d", null ],
+      [ "estimateWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#ac2269aefac9958545213fa85a1183408", null ],
+      [ "setWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#aa5ac0d95321d764e70c0fb18e55a4915", null ],
+      [ "estimateWorldGeometry", "class_ogre_1_1_bsp_scene_manager.html#a6efcddf31f81825c0092d0a60babda3b", null ],
       [ "showNodeBoxes", "class_ogre_1_1_bsp_scene_manager.html#a0f8a152457053472843eebfb6ec1bc0f", null ],
-      [ "getSuggestedViewpoint", "class_ogre_1_1_bsp_scene_manager.html#afbed035d6e010f7df4727b2ff76e0750", null ],
+      [ "getSuggestedViewpoint", "class_ogre_1_1_bsp_scene_manager.html#a12204c33556c1f3c22c5652b6aaafa1b", null ],
       [ "getLevel", "class_ogre_1_1_bsp_scene_manager.html#a201d0b4ed0ec67b8480092dee0a5184a", null ],
       [ "setLevel", "class_ogre_1_1_bsp_scene_manager.html#a344a49c8ef3b09b290b2e14c2bfa500d", null ],
-      [ "_findVisibleObjects", "class_ogre_1_1_bsp_scene_manager.html#a35b475390db15397c62881e4951b9051", null ],
-      [ "createSceneNodeImpl", "class_ogre_1_1_bsp_scene_manager.html#a6fabed7f85f1ff62845a11c5c824ba18", null ],
-      [ "createSceneNodeImpl", "class_ogre_1_1_bsp_scene_manager.html#ad20fc693dfce46a6d99b7c0d0aca9c27", null ],
+      [ "_findVisibleObjects", "class_ogre_1_1_bsp_scene_manager.html#a046c5bdaddb4c0595b6c79b10037f9e4", null ],
+      [ "createSceneNodeImpl", "class_ogre_1_1_bsp_scene_manager.html#add4847839039e485bee409f229b48b40", null ],
+      [ "createSceneNodeImpl", "class_ogre_1_1_bsp_scene_manager.html#a7d2c528a848b18c5c5296905737ee36c", null ],
       [ "_notifyObjectMoved", "class_ogre_1_1_bsp_scene_manager.html#af55b958c50f23943eca3132c8f154147", null ],
       [ "_notifyObjectDetached", "class_ogre_1_1_bsp_scene_manager.html#a884ea1e2f8b90a149f03de7b822c2385", null ],
-      [ "createRayQuery", "class_ogre_1_1_bsp_scene_manager.html#abcdea8bbb6c3fe84593322e794199821", null ],
-      [ "createIntersectionQuery", "class_ogre_1_1_bsp_scene_manager.html#a565c9a52e0c139f0c9fc1aa5856c1658", null ]
+      [ "createRayQuery", "class_ogre_1_1_bsp_scene_manager.html#a00bede8ae97fbfd56ae9a173aabb70e3", null ],
+      [ "createIntersectionQuery", "class_ogre_1_1_bsp_scene_manager.html#a99ebf10a5f443434fae8b3208f92d088", null ]
     ] ],
     [ "Ogre::BspSceneManagerFactory", "class_ogre_1_1_bsp_scene_manager_factory.html", [
-      [ "BspSceneManagerFactory", "class_ogre_1_1_bsp_scene_manager_factory.html#ac3cfb57b3ddfcff9c72723d62df466e4", null ],
-      [ "~BspSceneManagerFactory", "class_ogre_1_1_bsp_scene_manager_factory.html#ade95318da6085531e0ab86a2d7b6bcd9", null ],
-      [ "createInstance", "class_ogre_1_1_bsp_scene_manager_factory.html#aa421b5002cc903659a31aedc16bfdb72", null ],
+      [ "createInstance", "class_ogre_1_1_bsp_scene_manager_factory.html#a8d4635a141f5fb4a17ae0232d952f125", null ],
+      [ "getTypeName", "class_ogre_1_1_bsp_scene_manager_factory.html#a89483d387ff238f181ebb69e2c5b6e67", null ],
       [ "FACTORY_TYPE_NAME", "class_ogre_1_1_bsp_scene_manager_factory.html#a00c4e589af4d4dabea98be3556c71382", null ]
     ] ],
     [ "Ogre::BspSceneNode", "class_ogre_1_1_bsp_scene_node.html", [
       [ "BspSceneNode", "class_ogre_1_1_bsp_scene_node.html#a3c9fc7c13d2a9a92130e1b595f74fe8d", null ],
       [ "BspSceneNode", "class_ogre_1_1_bsp_scene_node.html#a387df029179fce1955902d2b6cd3ae8b", null ],
-      [ "_update", "class_ogre_1_1_bsp_scene_node.html#a1ee88a2f5a1f7fe70c4ea39a245aa6a1", null ],
-      [ "detachObject", "class_ogre_1_1_bsp_scene_node.html#ab63ee0b87970f654eadc3d43c59a8eb5", null ],
-      [ "detachObject", "class_ogre_1_1_bsp_scene_node.html#a888affced3515671eb916f6cca89c614", null ],
-      [ "detachAllObjects", "class_ogre_1_1_bsp_scene_node.html#aedb8690d7cd00a804a659eac1ee45060", null ]
+      [ "_update", "class_ogre_1_1_bsp_scene_node.html#a645083e5abba280774870d26518e48ba", null ],
+      [ "detachObject", "class_ogre_1_1_bsp_scene_node.html#ae01f2cdeee4fce08c95f2485fb3c5856", null ],
+      [ "detachObject", "class_ogre_1_1_bsp_scene_node.html#a7925beb519b3f99fd01ed813250ce95b", null ],
+      [ "detachAllObjects", "class_ogre_1_1_bsp_scene_node.html#a5aaba5c4f0ca1c0d896d9b9a753d78b1", null ]
     ] ],
     [ "Ogre::Quake3Level", "class_ogre_1_1_quake3_level.html", [
       [ "Quake3Level", "class_ogre_1_1_quake3_level.html#a34f3c49164fba86c97db55479f98204b", null ],
@@ -166,7 +171,7 @@ var group___b_s_p_scene_manager =
         [ "animNumFrames", "struct_ogre_1_1_quake3_shader_1_1_pass.html#addc13b69cc91bcd4ae2369ccc9395b80", null ],
         [ "frames", "struct_ogre_1_1_quake3_shader_1_1_pass.html#ab9dad7d52b2eefbf3258fd63d67e9d34", null ]
       ] ],
-      [ "PassList", "class_ogre_1_1_quake3_shader.html#ad7b3d5bf7769ee2f2a676e083e0bb095", null ],
+      [ "PassList", "class_ogre_1_1_quake3_shader.html#aba12a46a11f6e8b0b19f1498a400a6be", null ],
       [ "Quake3Shader", "class_ogre_1_1_quake3_shader.html#ac0b6f67499f46ba23725a05a0e60d17d", null ],
       [ "~Quake3Shader", "class_ogre_1_1_quake3_shader.html#a3efafbb73d988f264688b9717f27ce88", null ],
       [ "createAsMaterial", "class_ogre_1_1_quake3_shader.html#a4f1c3ec931337a69a7edcb2fa62cb0ee", null ],
@@ -187,14 +192,28 @@ var group___b_s_p_scene_manager =
     [ "Ogre::Quake3ShaderManager", "class_ogre_1_1_quake3_shader_manager.html", [
       [ "Quake3ShaderManager", "class_ogre_1_1_quake3_shader_manager.html#af2d238e94a372c870e1348ce91f9ad10", null ],
       [ "~Quake3ShaderManager", "class_ogre_1_1_quake3_shader_manager.html#ad533bdc0349934d72a80416f61320332", null ],
-      [ "getScriptPatterns", "class_ogre_1_1_quake3_shader_manager.html#a307ed600447e7633d58c8321c1f77ce5", null ],
-      [ "parseScript", "class_ogre_1_1_quake3_shader_manager.html#a7beb32399a0e8b0395024725ca4fbfcd", null ],
-      [ "getLoadingOrder", "class_ogre_1_1_quake3_shader_manager.html#acac48222f4be26855091e87db3b215f1", null ],
+      [ "getScriptPatterns", "class_ogre_1_1_quake3_shader_manager.html#a079c9d93c0b5f4076758763fb87b440b", null ],
+      [ "parseScript", "class_ogre_1_1_quake3_shader_manager.html#a33721e998819c9298a3f0fa4d708a4ff", null ],
+      [ "getLoadingOrder", "class_ogre_1_1_quake3_shader_manager.html#abb09d9ae90d45513cc4a08352f91d332", null ],
       [ "create", "class_ogre_1_1_quake3_shader_manager.html#aab8a07097e52cde7f056ed62bd2fa4c3", null ],
       [ "clear", "class_ogre_1_1_quake3_shader_manager.html#aa9db24c7fdb71cc3ffc9b4fbf7272e39", null ],
       [ "getByName", "class_ogre_1_1_quake3_shader_manager.html#ae1fabdd007bb92605be703071621ce1b", null ],
       [ "getSingleton", "class_ogre_1_1_quake3_shader_manager.html#aa0bad36e8df7664db8b328482b685248", null ],
       [ "getSingletonPtr", "class_ogre_1_1_quake3_shader_manager.html#a46aa2bf27c8c4e9a1a48897caf957c62", null ]
     ] ],
-    [ "Ogre::BspLevelPtr", "group___b_s_p_scene_manager.html#ga83b646ec80fbd38a752530bc86f77971", null ]
+    [ "Ogre::WorldFragment", "struct_ogre_1_1_world_fragment.html", [
+      [ "fragmentType", "struct_ogre_1_1_world_fragment.html#a95b204d1af457cd4b264831797bb1abf", null ],
+      [ "singleIntersection", "struct_ogre_1_1_world_fragment.html#a99febd2258d655b97d811d449bc39a2b", null ],
+      [ "planes", "struct_ogre_1_1_world_fragment.html#aa03b744a5ed87918575241cf81ad873c", null ],
+      [ "geometry", "struct_ogre_1_1_world_fragment.html#aa18b1aeb11d41f42e8ee59d5bfd47fcf", null ],
+      [ "renderOp", "struct_ogre_1_1_world_fragment.html#a057992735c3d3b6642ccf76fe2768841", null ]
+    ] ],
+    [ "Ogre::BspLevelPtr", "group___b_s_p_scene_manager.html#ga83b646ec80fbd38a752530bc86f77971", null ],
+    [ "Ogre::WorldFragmentType", "group___b_s_p_scene_manager.html#ga9d3d1b15230ef9bfab0ae4e8af2ceee7", [
+      [ "Ogre::WFT_NONE", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7aba2a479c0710afc0c5de7c790f78ca8d", null ],
+      [ "Ogre::WFT_PLANE_BOUNDED_REGION", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7a2fa4eedaa92804519c7245dcd7c1b3fd", null ],
+      [ "Ogre::WFT_SINGLE_INTERSECTION", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7a8de3089cc41bd7cc140633f9570c649b", null ],
+      [ "Ogre::WFT_CUSTOM_GEOMETRY", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7ad058d64707ba9f51443f7b2b18191c80", null ],
+      [ "Ogre::WFT_RENDER_OPERATION", "group___b_s_p_scene_manager.html#gga9d3d1b15230ef9bfab0ae4e8af2ceee7a360231a6b7fc29efff7dfd727d56a867", null ]
+    ] ]
 ];
\ No newline at end of file
