@@ -42,17 +42,19 @@ var group___input =
     [ "OgreBites::InputListenerChain", "class_ogre_bites_1_1_input_listener_chain.html", [
       [ "InputListenerChain", "class_ogre_bites_1_1_input_listener_chain.html#aab2e94286cf177a2b761d0e75d37087b", null ],
       [ "InputListenerChain", "class_ogre_bites_1_1_input_listener_chain.html#a7546843880a071e091df919c2b939e7a", null ],
+      [ "empty", "class_ogre_bites_1_1_input_listener_chain.html#ac6c5a0dd6ba4232f8e7ec2f87cd7b8f6", null ],
       [ "operator=", "class_ogre_bites_1_1_input_listener_chain.html#a65e92f89f937ffc2f081d6ac6f574600", null ],
-      [ "keyPressed", "class_ogre_bites_1_1_input_listener_chain.html#a2e60f6776ec415152625ab2025c94fed", null ],
-      [ "keyReleased", "class_ogre_bites_1_1_input_listener_chain.html#a7e94100b3187cb6a14f7159bde540c3c", null ],
-      [ "touchMoved", "class_ogre_bites_1_1_input_listener_chain.html#afb6a8dda62ef885cb5d8359ccde03986", null ],
-      [ "touchPressed", "class_ogre_bites_1_1_input_listener_chain.html#a5eb61e58353f941f2a1c30e42807986d", null ],
-      [ "touchReleased", "class_ogre_bites_1_1_input_listener_chain.html#aa43a57a2f3038c3613696bd06eb03389", null ],
-      [ "mouseMoved", "class_ogre_bites_1_1_input_listener_chain.html#a05384dfebfa856c863bf2393c3779ed6", null ],
-      [ "mouseWheelRolled", "class_ogre_bites_1_1_input_listener_chain.html#ac8801b6f76fe39a2a94838158fa7f52d", null ],
-      [ "mousePressed", "class_ogre_bites_1_1_input_listener_chain.html#a9bd7cb8fbba143d773fd66f1ff19af72", null ],
-      [ "mouseReleased", "class_ogre_bites_1_1_input_listener_chain.html#a9bff873cf9bb121a1dbd7430ebaf6d49", null ],
-      [ "textInput", "class_ogre_bites_1_1_input_listener_chain.html#ab087cceab90a40754471a143e26b6e82", null ]
+      [ "frameRendered", "class_ogre_bites_1_1_input_listener_chain.html#a84e948184c9e9efd1f9443b8d7da8284", null ],
+      [ "keyPressed", "class_ogre_bites_1_1_input_listener_chain.html#a89788643b896812d89878fb1e3c0042c", null ],
+      [ "keyReleased", "class_ogre_bites_1_1_input_listener_chain.html#ab69dcabeca45b0bb55af54baeb6cd2dd", null ],
+      [ "touchMoved", "class_ogre_bites_1_1_input_listener_chain.html#a2e6207262e833b9a2f90a38c9583ce15", null ],
+      [ "touchPressed", "class_ogre_bites_1_1_input_listener_chain.html#a8a842a2e85312f793b5b740419b6c22a", null ],
+      [ "touchReleased", "class_ogre_bites_1_1_input_listener_chain.html#a5ee5e6cb1ace0eeb4432648ee6c641f5", null ],
+      [ "mouseMoved", "class_ogre_bites_1_1_input_listener_chain.html#a214d717a9fdaf88339e2d2fcac43876c", null ],
+      [ "mouseWheelRolled", "class_ogre_bites_1_1_input_listener_chain.html#a8d055fbc83ba17d69798549e32308a21", null ],
+      [ "mousePressed", "class_ogre_bites_1_1_input_listener_chain.html#aa71fa8c78c11200ddfb46a3ff3fa79ba", null ],
+      [ "mouseReleased", "class_ogre_bites_1_1_input_listener_chain.html#aa8f55ade2ae16e8fa55776ea781ad941", null ],
+      [ "textInput", "class_ogre_bites_1_1_input_listener_chain.html#a6cd365c15071db536182f0dfd411bb65", null ]
     ] ],
     [ "OgreBites::KeyboardEvent", "struct_ogre_bites_1_1_keyboard_event.html", [
       [ "type", "struct_ogre_bites_1_1_keyboard_event.html#a43602aaa9c30b36a13c2c4b4eccbecd9", null ],
