@@ -30,12 +30,12 @@ var group___p_c_z_scene_manager =
       ] ],
       [ "PCZCamera", "class_ogre_1_1_p_c_z_camera.html#a203af6f72ce379e5f2a9469295187b7a", null ],
       [ "~PCZCamera", "class_ogre_1_1_p_c_z_camera.html#aee4e5b88dbe20f0a6f03618135fabde7", null ],
-      [ "getBoundingBox", "class_ogre_1_1_p_c_z_camera.html#a378066424841082400db41277ea698db", null ],
-      [ "isVisible", "class_ogre_1_1_p_c_z_camera.html#ab9b82c828c30942bfdb8ba54d112f511", null ],
+      [ "getBoundingBox", "class_ogre_1_1_p_c_z_camera.html#abd7e041206e4f36453e784b531b290c6", null ],
+      [ "isVisible", "class_ogre_1_1_p_c_z_camera.html#aa5e5ee66154a6c17804b52f1b1bc0a34", null ],
       [ "isVisible", "class_ogre_1_1_p_c_z_camera.html#a6f359238ef68a2175bd799bc2bf28030", null ],
       [ "isVisibile", "class_ogre_1_1_p_c_z_camera.html#a0a3632521a6f13e53b4bf1a8d006fb2e", null ],
       [ "getVisibility", "class_ogre_1_1_p_c_z_camera.html#aec5f399a2b78457c1ca0bb22b95efef9", null ],
-      [ "setProjectionType", "class_ogre_1_1_p_c_z_camera.html#a206f2cff460b3bd8957a32619f50038c", null ],
+      [ "setProjectionType", "class_ogre_1_1_p_c_z_camera.html#a9cc849a0862bb9ce23f7b7818ac64f7e", null ],
       [ "update", "class_ogre_1_1_p_c_z_camera.html#ac5d8ae8e58bed364960665fb02cf8675", null ],
       [ "addPortalCullingPlanes", "class_ogre_1_1_p_c_z_camera.html#afbacdc365ba31e1d3ace59928a338a7e", null ],
       [ "removePortalCullingPlanes", "class_ogre_1_1_p_c_z_camera.html#a4996a6818399957261493cb8a7646581", null ],
@@ -70,7 +70,7 @@ var group___p_c_z_scene_manager =
       [ "PCZLight", "class_ogre_1_1_p_c_z_light.html#ae62ec9e9fa36ca2c6072c8e08ddfaa4b", null ],
       [ "PCZLight", "class_ogre_1_1_p_c_z_light.html#a811b285754f1f752968a1cc0ddde3115", null ],
       [ "~PCZLight", "class_ogre_1_1_p_c_z_light.html#a7251ee6bfb370a5629da7aaa654b5485", null ],
-      [ "getMovableType", "class_ogre_1_1_p_c_z_light.html#a3798635d7639ab406e1617e2fc0f05c2", null ],
+      [ "getMovableType", "class_ogre_1_1_p_c_z_light.html#a4c6cf65608fffdb5e5f9c1c4bb067502", null ],
       [ "clearAffectedZones", "class_ogre_1_1_p_c_z_light.html#a4b128f16ec323ba495e9373da4800f2a", null ],
       [ "addZoneToAffectedZonesList", "class_ogre_1_1_p_c_z_light.html#a0d7d0bcc9aad97228ef7e40e41f7c7b6", null ],
       [ "affectsZone", "class_ogre_1_1_p_c_z_light.html#adfed7af8998a6ad31130820527476b37", null ],
@@ -78,14 +78,14 @@ var group___p_c_z_scene_manager =
       [ "setAffectsVisibleZone", "class_ogre_1_1_p_c_z_light.html#a41d865602a231b36ead55d751f4cd77d", null ],
       [ "updateZones", "class_ogre_1_1_p_c_z_light.html#a4830347df6db80de75f2054c3c1b647e", null ],
       [ "removeZoneFromAffectedZonesList", "class_ogre_1_1_p_c_z_light.html#ab0c63d9303a53d4fb735e11e0fac3f09", null ],
-      [ "_notifyMoved", "class_ogre_1_1_p_c_z_light.html#a6944ad4ba92212a50c7350dc7ecb06e9", null ],
+      [ "_notifyMoved", "class_ogre_1_1_p_c_z_light.html#ace6354632ef1c4c809d0e01711f2b8dc", null ],
       [ "clearNeedsUpdate", "class_ogre_1_1_p_c_z_light.html#a017e849f6d4adcffba153f80d9c8bbe6", null ],
       [ "getNeedsUpdate", "class_ogre_1_1_p_c_z_light.html#a2565a8e8a9ef516800ab6514dce61055", null ]
     ] ],
     [ "Ogre::PCZLightFactory", "class_ogre_1_1_p_c_z_light_factory.html", [
       [ "PCZLightFactory", "class_ogre_1_1_p_c_z_light_factory.html#a2c58d971af884e88775f8cf46fe7e75a", null ],
       [ "~PCZLightFactory", "class_ogre_1_1_p_c_z_light_factory.html#a7512e363b4db3fd110fe4307fd5c16e8", null ],
-      [ "getType", "class_ogre_1_1_p_c_z_light_factory.html#a1df8f520521e33a7fef2621dab27b9ea", null ],
+      [ "getType", "class_ogre_1_1_p_c_z_light_factory.html#a18b0d8505e778e57f04d965da62664e9", null ],
       [ "FACTORY_TYPE_NAME", "class_ogre_1_1_p_c_z_light_factory.html#ae943f1e7527419df075c47299e9c99cd", null ]
     ] ],
     [ "Ogre::PCZone", "class_ogre_1_1_p_c_zone.html", [
@@ -140,10 +140,10 @@ var group___p_c_z_scene_manager =
       [ "mPCZSM", "class_ogre_1_1_p_c_zone.html#a93e8f7a50cdea269e209fd15f87c557d", null ]
     ] ],
     [ "Ogre::PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html", [
-      [ "ZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#a44d7ec7900f22ea1a1dcaf62bbe65735", null ],
+      [ "ZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#abf3a446711cefeb7190e09b6ffaee330", null ],
       [ "PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html#ac6e44e60f66e1540d4c14a52aa36120c", null ],
       [ "~PCZSceneManager", "class_ogre_1_1_p_c_z_scene_manager.html#a6caa6bf780a9dd066385a14c68d1d8f2", null ],
-      [ "getTypeName", "class_ogre_1_1_p_c_z_scene_manager.html#a5407404105bd8151c13a9e71f92f3ed6", null ],
+      [ "getTypeName", "class_ogre_1_1_p_c_z_scene_manager.html#a4692cc30266e489209f652ae2fce2eff", null ],
       [ "init", "class_ogre_1_1_p_c_z_scene_manager.html#a93564bf4242ff46afd5bac6eb908fb4b", null ],
       [ "createPortal", "class_ogre_1_1_p_c_z_scene_manager.html#aa1bbab893e1482645607f7aa0985112e", null ],
       [ "destroyPortal", "class_ogre_1_1_p_c_z_scene_manager.html#a97e82454f91110f27d08f4873eec2c5b", null ],
@@ -155,22 +155,21 @@ var group___p_c_z_scene_manager =
       [ "setZoneGeometry", "class_ogre_1_1_p_c_z_scene_manager.html#a1d81a09d8ddbd08f4cbbd2fd74b121ab", null ],
       [ "createSceneNodeImpl", "class_ogre_1_1_p_c_z_scene_manager.html#abdad18e34d3fb9ac355bfa186726f4c1", null ],
       [ "createSceneNodeImpl", "class_ogre_1_1_p_c_z_scene_manager.html#ae16b9aad2c729ecf643ee4befa2c1299", null ],
-      [ "createCamera", "class_ogre_1_1_p_c_z_scene_manager.html#a3776038ae91d7d83f5120b560f133bdf", null ],
-      [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a7c05feff15ab079e93a8d96874f0798e", null ],
-      [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a825cdc9ea0e5ab83c9e2211d91937999", null ],
-      [ "clearScene", "class_ogre_1_1_p_c_z_scene_manager.html#a8460e2cb577bdedf7848c690c105e6aa", null ],
+      [ "createCamera", "class_ogre_1_1_p_c_z_scene_manager.html#a54678fa02c98f4b336c789f5b59720ea", null ],
+      [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a5dd6a7a34675a51deebfeb51250e3837", null ],
+      [ "destroySceneNode", "class_ogre_1_1_p_c_z_scene_manager.html#a92a76aaee441c37b02eefe5291818d56", null ],
+      [ "clearScene", "class_ogre_1_1_p_c_z_scene_manager.html#a91a18704ec2eb46ba4910cb39c43662d", null ],
       [ "setWorldGeometryRenderQueue", "class_ogre_1_1_p_c_z_scene_manager.html#a222a1701e1a9453b0143ea9a0076cca0", null ],
-      [ "_renderScene", "class_ogre_1_1_p_c_z_scene_manager.html#ae82654ed4ae10749be67c82543ad2e82", null ],
-      [ "enableSky", "class_ogre_1_1_p_c_z_scene_manager.html#ab8d72278febf0c639d439a1522881c4c", null ],
+      [ "_renderScene", "class_ogre_1_1_p_c_z_scene_manager.html#a8fe6aa9f9cd27ca47969edb121846f27", null ],
+      [ "enableSky", "class_ogre_1_1_p_c_z_scene_manager.html#a6f01db5bc19df9229e7ceb6c01b06dfa", null ],
       [ "setSkyZone", "class_ogre_1_1_p_c_z_scene_manager.html#aab8c479c11d401a917e3471fbfc49bfe", null ],
-      [ "_updateSceneGraph", "class_ogre_1_1_p_c_z_scene_manager.html#a0e8ddd07155c1812cf91b17684dfd07a", null ],
-      [ "_findVisibleObjects", "class_ogre_1_1_p_c_z_scene_manager.html#af0d5b6993d1e969077caada228dcb484", null ],
-      [ "_alertVisibleObjects", "class_ogre_1_1_p_c_z_scene_manager.html#abef263f139e24281791a4c9e9ac5fe61", null ],
-      [ "createLight", "class_ogre_1_1_p_c_z_scene_manager.html#a161dc9dedf2eb4e5162b78eed78c54cc", null ],
-      [ "getLight", "class_ogre_1_1_p_c_z_scene_manager.html#aa31dba785134c39aa610269b337f527b", null ],
-      [ "hasLight", "class_ogre_1_1_p_c_z_scene_manager.html#a124d44a99f4cf9cd501c77b8107fce99", null ],
-      [ "destroyLight", "class_ogre_1_1_p_c_z_scene_manager.html#af421911418053da91e16d6c456050951", null ],
-      [ "destroyAllLights", "class_ogre_1_1_p_c_z_scene_manager.html#a6529811d0646cf2c938daf2cf8373fe0", null ],
+      [ "_updateSceneGraph", "class_ogre_1_1_p_c_z_scene_manager.html#a2422a7d20a51b0ce63b16b8549cc5bf3", null ],
+      [ "_findVisibleObjects", "class_ogre_1_1_p_c_z_scene_manager.html#afea89abce2823af9c60eac169e6c643c", null ],
+      [ "createLight", "class_ogre_1_1_p_c_z_scene_manager.html#a56cf001fd734e8cc410d77f758d269f3", null ],
+      [ "getLight", "class_ogre_1_1_p_c_z_scene_manager.html#a9f0834156627c57d1ca3aa2546119a9c", null ],
+      [ "hasLight", "class_ogre_1_1_p_c_z_scene_manager.html#a1a3d1b6287f99d0a2d4e533a481bdd47", null ],
+      [ "destroyLight", "class_ogre_1_1_p_c_z_scene_manager.html#aee2ad35c6d3e4aef9fe6f9fff897264b", null ],
+      [ "destroyAllLights", "class_ogre_1_1_p_c_z_scene_manager.html#a46e55cdda71917942ac615491d65b027", null ],
       [ "_updatePortalZoneData", "class_ogre_1_1_p_c_z_scene_manager.html#a12ec71ae075484bcdee518bbecfcdf42", null ],
       [ "_dirtyNodeByMovingPortals", "class_ogre_1_1_p_c_z_scene_manager.html#a3ba0b3c24201c909927ece0792ea2cc7", null ],
       [ "_updatePCZSceneNodes", "class_ogre_1_1_p_c_z_scene_manager.html#a2bdd0173a377fdb56d51a52467bd5856", null ],
@@ -193,18 +192,18 @@ var group___p_c_z_scene_manager =
       [ "getDefaultZone", "class_ogre_1_1_p_c_z_scene_manager.html#a37b710d37afd14f1a028bdb9dd26151e", null ],
       [ "getZoneByName", "class_ogre_1_1_p_c_z_scene_manager.html#a53d963984aefa442b6c9dc20c9a34f4a", null ],
       [ "setShowPortals", "class_ogre_1_1_p_c_z_scene_manager.html#a25cba02e4766d9511b03684295ce73c7", null ],
-      [ "setOption", "class_ogre_1_1_p_c_z_scene_manager.html#ac780cbd313b0069999bedfa01ce1aae8", null ],
-      [ "getOption", "class_ogre_1_1_p_c_z_scene_manager.html#ae3230958f5f0c1126dd3942723e97531", null ],
-      [ "getOptionValues", "class_ogre_1_1_p_c_z_scene_manager.html#aacae43241e0d47c030432ea037c7d2d9", null ],
-      [ "getOptionKeys", "class_ogre_1_1_p_c_z_scene_manager.html#a717f6191cb79b3e15f75919e8627cdb5", null ],
-      [ "createAABBQuery", "class_ogre_1_1_p_c_z_scene_manager.html#abc8a86189d03593d100f83b0944d36fd", null ],
-      [ "createSphereQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a9733efff71a79c659bccc110962cced4", null ],
-      [ "createPlaneBoundedVolumeQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a0233993475336f800cda66ad647f6602", null ],
-      [ "createRayQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a2dac3e9f9d26656e740f86d6a53b8722", null ],
-      [ "createIntersectionQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a3ce6f090c7be77627df17f2e1f9e396f", null ],
+      [ "setOption", "class_ogre_1_1_p_c_z_scene_manager.html#a147e7252e3cd19ad9c09e0a02e9b3a44", null ],
+      [ "getOption", "class_ogre_1_1_p_c_z_scene_manager.html#ada9a794e741792754ec78b0cb89e7a9c", null ],
+      [ "getOptionValues", "class_ogre_1_1_p_c_z_scene_manager.html#ac24f28929b4e0ea49e4c7dac9f11c9c3", null ],
+      [ "getOptionKeys", "class_ogre_1_1_p_c_z_scene_manager.html#ac77f8127d6709de6858dbc991de7c3ef", null ],
+      [ "createAABBQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a315e2001409ef99dbdba24ef9d4c684f", null ],
+      [ "createSphereQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a3e1592ab984057791b468b0c1a538f48", null ],
+      [ "createPlaneBoundedVolumeQuery", "class_ogre_1_1_p_c_z_scene_manager.html#ab3cb3c5dda5c4779ecc7b3acd1b0189f", null ],
+      [ "createRayQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a3c5eea51ce8ea204bbbc786a8df311c0", null ],
+      [ "createIntersectionQuery", "class_ogre_1_1_p_c_z_scene_manager.html#aa194a8264693295fcbcdd14b9e8d325c", null ],
       [ "getZoneIterator", "class_ogre_1_1_p_c_z_scene_manager.html#ad8c3bdeb482268348587406720128530", null ],
       [ "_clearAllZonesPortalUpdateFlag", "class_ogre_1_1_p_c_z_scene_manager.html#a6b5ba29779d8d03ac92b65bd21ea615d", null ],
-      [ "prepareShadowTextures", "class_ogre_1_1_p_c_z_scene_manager.html#a83ecec8625002cc0cd6012fd78661337", null ],
+      [ "prepareShadowTextures", "class_ogre_1_1_p_c_z_scene_manager.html#a68f3a812b4dd986e1f84ed27223e4963", null ],
       [ "PCZIntersectionSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a66e03b2e49e35a0f0d2b6795855e5f20", null ],
       [ "PCZRaySceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#ae08bc00b90e82c22fd5281b87c0c76f4", null ],
       [ "PCZSphereSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a0f46ad3758026a3cefff77b8313fb084", null ],
@@ -212,17 +211,16 @@ var group___p_c_z_scene_manager =
       [ "PCZPlaneBoundedVolumeListSceneQuery", "class_ogre_1_1_p_c_z_scene_manager.html#a7ad4f1ee5e2004e94292aaa8ea5a0bc1", null ]
     ] ],
     [ "Ogre::PCZSceneManagerFactory", "class_ogre_1_1_p_c_z_scene_manager_factory.html", [
-      [ "PCZSceneManagerFactory", "class_ogre_1_1_p_c_z_scene_manager_factory.html#aa038bd53f6437f70dd90e0734154398a", null ],
-      [ "~PCZSceneManagerFactory", "class_ogre_1_1_p_c_z_scene_manager_factory.html#a013fdc30fa1e2f408bf7057d39d1be2b", null ],
-      [ "createInstance", "class_ogre_1_1_p_c_z_scene_manager_factory.html#a580430f27538648b674b1e5f23693e98", null ],
+      [ "createInstance", "class_ogre_1_1_p_c_z_scene_manager_factory.html#ab602b191fcbf40251b8e890021028c36", null ],
+      [ "getTypeName", "class_ogre_1_1_p_c_z_scene_manager_factory.html#afc193bcbd152dcdfa20423937a01b6a3", null ],
       [ "FACTORY_TYPE_NAME", "class_ogre_1_1_p_c_z_scene_manager_factory.html#ac1149fd3168410fdedf4c09c1deb85d1", null ]
     ] ],
     [ "Ogre::PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html", [
       [ "PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a28325ac8e36f3ad4063670b6f0e0078a", null ],
       [ "PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a6d29c74d3792328118cafe867445287d", null ],
       [ "~PCZSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a9cb1ec437e14d283253a49ece7c9c144", null ],
-      [ "_update", "class_ogre_1_1_p_c_z_scene_node.html#a2400498d4d82a3b910405f31f2a05f9c", null ],
-      [ "updateFromParentImpl", "class_ogre_1_1_p_c_z_scene_node.html#ae4cc6e09aa5f47bc460c2f9cbb96ed5c", null ],
+      [ "_update", "class_ogre_1_1_p_c_z_scene_node.html#afdf56660f1aee5a3e0104ad40b059e34", null ],
+      [ "updateFromParentImpl", "class_ogre_1_1_p_c_z_scene_node.html#ad3b9cbbd7c0c4ff4b149840599946b6b", null ],
       [ "createChildSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a020b91598e30fc8591130b7e15a7c729", null ],
       [ "createChildSceneNode", "class_ogre_1_1_p_c_z_scene_node.html#a3bb49869d0cb70b720113103a2c77d7b", null ],
       [ "getHomeZone", "class_ogre_1_1_p_c_z_scene_node.html#a27733c2fae1da581743dd406e6910a9e", null ],
