@@ -4,10 +4,10 @@ var group___terrain =
       [ "DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html", [
         [ "DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#aefc4903a668c681052b0a0186b4f5bc9", null ],
         [ "~DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#acc6a126be76a2f958d24c940ca42a8e3", null ],
-        [ "allocateVertexBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#aab7c65d2cb7af5c84670c996c389bffb", null ],
-        [ "freeVertexBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#af98bc1200700effb840c37f3d7b60b6f", null ],
-        [ "getSharedIndexBuffer", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#a34f2a33f27ae8732c4b034047929f56f", null ],
-        [ "freeAllBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#a13c9b9478bc9a473ce46e0dc62e88854", null ],
+        [ "allocateVertexBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#a698d20967fcd629365ec575e3bdddc4a", null ],
+        [ "freeVertexBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#abbab9b7b467b4783b9a43ac18261c0cf", null ],
+        [ "getSharedIndexBuffer", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#ab64c66761d093b621a75d68fa94c9d23", null ],
+        [ "freeAllBuffers", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#af2ae0b441f30b0204815e46aba27725b", null ],
         [ "warmStart", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html#ad52747460145f8b432fdfe7da0512057", null ]
       ] ],
       [ "GpuBufferAllocator", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html", [
@@ -44,8 +44,8 @@ var group___terrain =
         [ "worldSize", "struct_ogre_1_1_terrain_1_1_layer_instance.html#a54f726e8a0c17ec1579a16afa1a9398c", null ],
         [ "textureNames", "struct_ogre_1_1_terrain_1_1_layer_instance.html#a14363e8e526e90ea47ea93cac3764fc1", null ]
       ] ],
-      [ "RealVector", "class_ogre_1_1_terrain.html#a8e3b80784aa7c62ca578c2f8e2a01c7c", null ],
-      [ "LayerInstanceList", "class_ogre_1_1_terrain.html#a58751c7f151873a6e5cf03f59aa9ec47", null ],
+      [ "RealVector", "class_ogre_1_1_terrain.html#a73ee350d02e7d9805db61c740afcab87", null ],
+      [ "LayerInstanceList", "class_ogre_1_1_terrain.html#a24f7a399f8e60b335776064227b869d6", null ],
       [ "Alignment", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91", [
         [ "ALIGN_X_Z", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91ac4699c4f99bea344a309d5544b33c140", null ],
         [ "ALIGN_X_Y", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91adfc96b5a388b3e48709d56b899098508", null ],
@@ -185,8 +185,8 @@ var group___terrain =
       [ "getCompositeMapMaterial", "class_ogre_1_1_terrain.html#abde5a9931a278de23697fe6996a0e6d9", null ],
       [ "_getCompositeMapMaterial", "class_ogre_1_1_terrain.html#a53a08891b2dec0febd07bde5680598e7", null ],
       [ "getMaterialName", "class_ogre_1_1_terrain.html#adc32dec06092d0cdf5c89830aa217d41", null ],
-      [ "preFindVisibleObjects", "class_ogre_1_1_terrain.html#ad9bd9a0fbdb32cb5571cca586f21e811", null ],
-      [ "sceneManagerDestroyed", "class_ogre_1_1_terrain.html#a09baa91af04f211ee9e8e8f60d9e6c39", null ],
+      [ "preFindVisibleObjects", "class_ogre_1_1_terrain.html#ac1f87183250b885c01270a68d80236e4", null ],
+      [ "sceneManagerDestroyed", "class_ogre_1_1_terrain.html#a5f7edff06d941d5621aad56c7d19c939", null ],
       [ "getRenderQueueGroup", "class_ogre_1_1_terrain.html#a85c8ed1f55d5cf5300e2ccc2d02ab2f5", null ],
       [ "setRenderQueueGroup", "class_ogre_1_1_terrain.html#a9ff521bcc0fb0193d9105af627af5c0d", null ],
       [ "getVisibilityFlags", "class_ogre_1_1_terrain.html#a124354ea9deb52eced5e1d5a75a2b996", null ],
@@ -216,11 +216,6 @@ var group___terrain =
       [ "_setLightMapRequired", "class_ogre_1_1_terrain.html#a915121f91285f370bd1a01842991ae03", null ],
       [ "_setCompositeMapRequired", "class_ogre_1_1_terrain.html#a10b9f303b81585c1b51d0c273f03a5dd", null ],
       [ "_getUseVertexCompression", "class_ogre_1_1_terrain.html#a3b379afd3348efd5c8e5a87f0b2d0729", null ],
-      [ "canHandleRequest", "class_ogre_1_1_terrain.html#a22196f59f8f761e7fc4bea11db488252", null ],
-      [ "handleRequest", "class_ogre_1_1_terrain.html#a09fa76cb7d0c852aa15b5beb7a0433ea", null ],
-      [ "canHandleResponse", "class_ogre_1_1_terrain.html#a3e3d8150704d279630a3a125b0439138", null ],
-      [ "handleResponse", "class_ogre_1_1_terrain.html#ad963dbee0f58e887e05c982385fb9799", null ],
-      [ "handleGenerateMaterialResponse", "class_ogre_1_1_terrain.html#a584b511e44e1c33c387987187446353a", null ],
       [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#aca2087cd57d5c80ccf2e983acddb1887", null ],
       [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#a2f98ad8c78b6046d4d4f4dcf9d367fae", null ],
       [ "getQuadTree", "class_ogre_1_1_terrain.html#a69e78ec7eab8aece2d20df966f0dce49", null ],
@@ -251,7 +246,6 @@ var group___terrain =
       [ "TERRAIN_CHUNK_ID", "class_ogre_1_1_terrain.html#ad1b6d65618e1ebc55155214f3b10b337", null ],
       [ "TERRAIN_CHUNK_VERSION", "class_ogre_1_1_terrain.html#afd3641ddf000f3e2ca771408f558131b", null ],
       [ "TERRAIN_MAX_BATCH_SIZE", "class_ogre_1_1_terrain.html#a5c204799a40adae8b01411ec05dbc841", null ],
-      [ "TERRAIN_GENERATE_MATERIAL_INTERVAL_MS", "class_ogre_1_1_terrain.html#a1333f67a868e2e38123ab5c4532cc8e1", null ],
       [ "TERRAINLAYERDECLARATION_CHUNK_ID", "class_ogre_1_1_terrain.html#ac83d9fa6c4ba65db9c7ad66bbd01b0de", null ],
       [ "TERRAINLAYERDECLARATION_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a14ce718231ed706aec11489fc6843d76", null ],
       [ "TERRAINLAYERSAMPLER_CHUNK_ID", "class_ogre_1_1_terrain.html#a53d1561777a42b20c5aa5a42dd96bf9b", null ],
@@ -268,9 +262,7 @@ var group___terrain =
       [ "DERIVED_DATA_DELTAS", "class_ogre_1_1_terrain.html#adc4deb8ce09c46f3d6215ea1ff390959", null ],
       [ "DERIVED_DATA_NORMALS", "class_ogre_1_1_terrain.html#a633492f40707af756814bca31f0f35ba", null ],
       [ "DERIVED_DATA_LIGHTMAP", "class_ogre_1_1_terrain.html#a1ebde7f1f98abe26938397f7110c88f3", null ],
-      [ "DERIVED_DATA_ALL", "class_ogre_1_1_terrain.html#aaef9ac3a5d1ceed0260a17f93b88d848", null ],
-      [ "WORKQUEUE_DERIVED_DATA_REQUEST", "class_ogre_1_1_terrain.html#a0441ddb006dede009b3725e0a5536bba", null ],
-      [ "WORKQUEUE_GENERATE_MATERIAL_REQUEST", "class_ogre_1_1_terrain.html#aaa21ee42164657f45f932c5f70c590a0", null ]
+      [ "DERIVED_DATA_ALL", "class_ogre_1_1_terrain.html#aaef9ac3a5d1ceed0260a17f93b88d848", null ]
     ] ],
     [ "Ogre::TerrainAutoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod.html", [
       [ "~TerrainAutoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod.html#aceb9152f5d90b3477916a455cb9e453c", null ],
@@ -278,8 +270,8 @@ var group___terrain =
       [ "getStrategyId", "class_ogre_1_1_terrain_auto_update_lod.html#ac4f8917cf562b6ca232f5354fcfa13b3", null ]
     ] ],
     [ "Ogre::TerrainAutoUpdateLodByDistance", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html", [
-      [ "autoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html#ae968774d027e9b95cdc8d7519ce7de94", null ],
-      [ "getStrategyId", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html#a665518d7780157d43317459027216837", null ]
+      [ "autoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html#aa3c5f7032acaa7eae8f7c7f558fe316b", null ],
+      [ "getStrategyId", "class_ogre_1_1_terrain_auto_update_lod_by_distance.html#a92b1da2b733414d315deca08cf90ed87", null ]
     ] ],
     [ "Ogre::TerrainAutoUpdateLodFactory", "class_ogre_1_1_terrain_auto_update_lod_factory.html", [
       [ "getAutoUpdateLod", "class_ogre_1_1_terrain_auto_update_lod_factory.html#a25bb17eed297bd5986ace6f2836e86df", null ]
@@ -312,7 +304,7 @@ var group___terrain =
       [ "getUseRayBoxDistanceCalculation", "class_ogre_1_1_terrain_global_options.html#a41a60bd9535039a3d29b07fdf4124b32", null ],
       [ "setUseRayBoxDistanceCalculation", "class_ogre_1_1_terrain_global_options.html#a405c05d36af7a415b4aadf05492976de", null ],
       [ "getDefaultMaterialGenerator", "class_ogre_1_1_terrain_global_options.html#a01856a71b813370bc57839da50eb76c8", null ],
-      [ "setDefaultMaterialGenerator", "class_ogre_1_1_terrain_global_options.html#ae4311ab0c8bf4a1014dc55471b7084d1", null ],
+      [ "setDefaultMaterialGenerator", "class_ogre_1_1_terrain_global_options.html#a6a95aff2e0ef49d043f4591833a7cb94", null ],
       [ "getLayerBlendMapSize", "class_ogre_1_1_terrain_global_options.html#abaaf803e7181e4151ae053f8f3b1ca54", null ],
       [ "setLayerBlendMapSize", "class_ogre_1_1_terrain_global_options.html#a629f5b31ac27bc8b19d0dcf9ddc9bc9f", null ],
       [ "getDefaultLayerTextureWorldSize", "class_ogre_1_1_terrain_global_options.html#a0da4e02bc802061f23c2756117e7f9a6", null ],
@@ -355,10 +347,10 @@ var group___terrain =
         [ "filename", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a5b0c56d3b577d08fd3800f0399ac8bff", null ],
         [ "importData", "struct_ogre_1_1_terrain_group_1_1_terrain_slot_definition.html#a13c37aea760bd2537db790c8cf6271ce", null ]
       ] ],
-      [ "TerrainList", "class_ogre_1_1_terrain_group.html#a3f3ae22bcd04cf0e5e54e9975f8096a1", null ],
-      [ "TerrainSlotMap", "class_ogre_1_1_terrain_group.html#ab844d8ea2a2b5ac755caba4056963f72", null ],
-      [ "TerrainIterator", "class_ogre_1_1_terrain_group.html#a0ede78efc787db283ade7fdf25f85fe5", null ],
-      [ "ConstTerrainIterator", "class_ogre_1_1_terrain_group.html#a715d18edfe80acd905f82e69145b58ce", null ],
+      [ "TerrainList", "class_ogre_1_1_terrain_group.html#abf87821742631bea71b9023c25086b1c", null ],
+      [ "TerrainSlotMap", "class_ogre_1_1_terrain_group.html#ac57f832848da942340db29a5f7f02cde", null ],
+      [ "TerrainIterator", "class_ogre_1_1_terrain_group.html#a15497d38a2ad5c76905ad7f22f665151", null ],
+      [ "ConstTerrainIterator", "class_ogre_1_1_terrain_group.html#a28ce249f802a03bf7260885a156c9462", null ],
       [ "TerrainGroup", "class_ogre_1_1_terrain_group.html#a7be4b53fbb7f1edd7707c69b4ee883f4", null ],
       [ "TerrainGroup", "class_ogre_1_1_terrain_group.html#a1ceb1403ef71bd8c5badd1861f17a566", null ],
       [ "~TerrainGroup", "class_ogre_1_1_terrain_group.html#a8fa89b425d4ce101a4f3973096d204b2", null ],
@@ -409,10 +401,6 @@ var group___terrain =
       [ "getTerrainIterator", "class_ogre_1_1_terrain_group.html#ab3a50caf08ce5049ed0a15c0f610523d", null ],
       [ "getTerrainIterator", "class_ogre_1_1_terrain_group.html#a258a6c8f9655fc48fd4afbfaf9f650dd", null ],
       [ "getTerrainSlots", "class_ogre_1_1_terrain_group.html#ac8bb7d5a26fdfeec8dc7110d46a41aec", null ],
-      [ "canHandleRequest", "class_ogre_1_1_terrain_group.html#a008f51c172bd858cca8763af865f3fa1", null ],
-      [ "handleRequest", "class_ogre_1_1_terrain_group.html#acad15d3ffca3b36c0891d9012e0e5ffe", null ],
-      [ "canHandleResponse", "class_ogre_1_1_terrain_group.html#ad608848047850ff730ef870457b7e14f", null ],
-      [ "handleResponse", "class_ogre_1_1_terrain_group.html#a5d062f88928dd1a572dc7a411b07457b", null ],
       [ "packIndex", "class_ogre_1_1_terrain_group.html#ae56023a560b2b3e650d722e6e95e734c", null ],
       [ "unpackIndex", "class_ogre_1_1_terrain_group.html#a041018a20d3605dd54bdbdbca20df587", null ],
       [ "generateFilename", "class_ogre_1_1_terrain_group.html#a80e7857e742770fd6f6c97d3d68461c8", null ],
@@ -426,7 +414,6 @@ var group___terrain =
       [ "autoUpdateLod", "class_ogre_1_1_terrain_group.html#ac8d34ec8ee538ca6d917c7a6302310fd", null ],
       [ "autoUpdateLodAll", "class_ogre_1_1_terrain_group.html#a4c6fa825170af7191d061c273349cd88", null ],
       [ "getNumTerrainPrepareRequests", "class_ogre_1_1_terrain_group.html#aa6f3102a07e1768367b3c2e2c093c272", null ],
-      [ "WORKQUEUE_LOAD_REQUEST", "class_ogre_1_1_terrain_group.html#a93836a9bf0faed8a783e65a6f494a633", null ],
       [ "CHUNK_ID", "class_ogre_1_1_terrain_group.html#af5d1ab56ff789b227e25e2011877c224", null ],
       [ "CHUNK_VERSION", "class_ogre_1_1_terrain_group.html#a18b58f7ef72dae5943447a3167b61150", null ]
     ] ],
@@ -453,27 +440,12 @@ var group___terrain =
       [ "loadImage", "class_ogre_1_1_terrain_layer_blend_map.html#ae9713419de094e337f0dcef41dd9302d", null ],
       [ "update", "class_ogre_1_1_terrain_layer_blend_map.html#a7b84ae6db639c23977a433047ec955bb", null ]
     ] ],
-    [ "Ogre::TerrainLayerDeclaration", "struct_ogre_1_1_terrain_layer_declaration.html", [
-      [ "operator==", "struct_ogre_1_1_terrain_layer_declaration.html#a31b7b17f591169a464040af3f18488c6", null ],
-      [ "samplers", "struct_ogre_1_1_terrain_layer_declaration.html#a3beefe92183cb240f5810553909f7bde", null ],
-      [ "elements", "struct_ogre_1_1_terrain_layer_declaration.html#a4eaf6c95757b0031e0e7191632bb4fd0", null ]
-    ] ],
     [ "Ogre::TerrainLayerSampler", "struct_ogre_1_1_terrain_layer_sampler.html", [
       [ "TerrainLayerSampler", "struct_ogre_1_1_terrain_layer_sampler.html#a8cf27ef7b384897c434ea13670fb3231", null ],
       [ "TerrainLayerSampler", "struct_ogre_1_1_terrain_layer_sampler.html#a99aefff53a235d471bb54d65c8ec0483", null ],
-      [ "operator==", "struct_ogre_1_1_terrain_layer_sampler.html#ab839152454b0d646a429a9391b40f82b", null ],
       [ "alias", "struct_ogre_1_1_terrain_layer_sampler.html#ade7747cc8625094da5ed01bc5ab3e19c", null ],
       [ "format", "struct_ogre_1_1_terrain_layer_sampler.html#acbf57cf471d575ffc862c50d15bad9b0", null ]
     ] ],
-    [ "Ogre::TerrainLayerSamplerElement", "struct_ogre_1_1_terrain_layer_sampler_element.html", [
-      [ "TerrainLayerSamplerElement", "struct_ogre_1_1_terrain_layer_sampler_element.html#af648e0695b3baa049d586e82e2194e1f", null ],
-      [ "TerrainLayerSamplerElement", "struct_ogre_1_1_terrain_layer_sampler_element.html#ae471dccbe80e8580b943b3883e40b571", null ],
-      [ "operator==", "struct_ogre_1_1_terrain_layer_sampler_element.html#ac4969d689a4c197ea5b006f0d97669d9", null ],
-      [ "source", "struct_ogre_1_1_terrain_layer_sampler_element.html#a96b4bc009cc033a8b6d5c32aaffd2bbd", null ],
-      [ "semantic", "struct_ogre_1_1_terrain_layer_sampler_element.html#afd77757659bd8b5f5672a34168071963", null ],
-      [ "elementStart", "struct_ogre_1_1_terrain_layer_sampler_element.html#a82f5e76d137cfc061c99fa1458a2abb4", null ],
-      [ "elementCount", "struct_ogre_1_1_terrain_layer_sampler_element.html#a1f5544d50fad51034e72258400eb561b", null ]
-    ] ],
     [ "Ogre::TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html", [
       [ "LoadLodRequest", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html", [
         [ "LoadLodRequest", "struct_ogre_1_1_terrain_lod_manager_1_1_load_lod_request.html#a3c4ff828ba353197bb73965263f71b02", null ],
@@ -489,18 +461,14 @@ var group___terrain =
         [ "resolution", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#a872db0ab4ff69396406a84eedf7f194a", null ],
         [ "size", "struct_ogre_1_1_terrain_lod_manager_1_1_lod_info.html#ae043b0b854b4dedb4f658b4f37e12727", null ]
       ] ],
-      [ "LodData", "class_ogre_1_1_terrain_lod_manager.html#a2160fbde7892625afa141be746794699", null ],
-      [ "LodsData", "class_ogre_1_1_terrain_lod_manager.html#a483e8ac5b9f072494b921fff1e574551", null ],
+      [ "LodData", "class_ogre_1_1_terrain_lod_manager.html#af4f58f0e55b2be3751224540ca56afae", null ],
+      [ "LodsData", "class_ogre_1_1_terrain_lod_manager.html#aae4e8b93b5c0d7a49eaa9f5acc0c939d", null ],
       [ "TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html#ab5f4ef928bce023bc3ac359191e8c379", null ],
       [ "TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html#a9a14a5692b839d0c0a68c0111fb9192a", null ],
       [ "~TerrainLodManager", "class_ogre_1_1_terrain_lod_manager.html#adb27b3785755085b8aadf0c46a35bc27", null ],
       [ "open", "class_ogre_1_1_terrain_lod_manager.html#a72dc6e789390e1a53e36fafff3dd0a83", null ],
       [ "close", "class_ogre_1_1_terrain_lod_manager.html#a465ed43292cb995eaf83e17754d12841", null ],
       [ "isOpen", "class_ogre_1_1_terrain_lod_manager.html#a94980c3f507f89eb98a92bb551b91a60", null ],
-      [ "canHandleRequest", "class_ogre_1_1_terrain_lod_manager.html#af274ee16de8e9ddf1f058a2eb0ea1b5e", null ],
-      [ "canHandleResponse", "class_ogre_1_1_terrain_lod_manager.html#a0aa9184563866da3d6de2ed040bc6667", null ],
-      [ "handleRequest", "class_ogre_1_1_terrain_lod_manager.html#ae493a105b7b4db7d8393b45a1fb9c50a", null ],
-      [ "handleResponse", "class_ogre_1_1_terrain_lod_manager.html#a10e9a78d1a3206e6fdb377512013dc5b", null ],
       [ "updateToLodLevel", "class_ogre_1_1_terrain_lod_manager.html#a8c073c4b9f1f84603e008f0fd04d5384", null ],
       [ "saveLodData", "class_ogre_1_1_terrain_lod_manager.html#a30145b19986f072ec285f6e5bce8f448", null ],
       [ "fillBufferAtLod", "class_ogre_1_1_terrain_lod_manager.html#a116f798c0ba155a908fcbc662f762ee6", null ],
@@ -511,86 +479,74 @@ var group___terrain =
       [ "getTargetLodLevel", "class_ogre_1_1_terrain_lod_manager.html#aa7efa60b04102e08f549982ec8d82f4a", null ],
       [ "getLodInfo", "class_ogre_1_1_terrain_lod_manager.html#a05040b4f7d8503b9bc8777ac20c5f922", null ],
       [ "TERRAINLODDATA_CHUNK_ID", "class_ogre_1_1_terrain_lod_manager.html#a81d661a66427c9f136fa27e4b328b6db", null ],
-      [ "TERRAINLODDATA_CHUNK_VERSION", "class_ogre_1_1_terrain_lod_manager.html#a70d6a9494e245040a45b5ee000334b1e", null ],
-      [ "WORKQUEUE_LOAD_LOD_DATA_REQUEST", "class_ogre_1_1_terrain_lod_manager.html#a20d40da6357fb06efdfc72034ce5f424", null ]
+      [ "TERRAINLODDATA_CHUNK_VERSION", "class_ogre_1_1_terrain_lod_manager.html#a70d6a9494e245040a45b5ee000334b1e", null ]
     ] ],
     [ "Ogre::TerrainMaterialGenerator", "class_ogre_1_1_terrain_material_generator.html", [
-      [ "Profile", "class_ogre_1_1_terrain_material_generator_1_1_profile.html", [
-        [ "Profile", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a7ef6164f52f51368b1a4f7496c262669", null ],
-        [ "Profile", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a8b8528902ca05c44ce41a4a4802f0769", null ],
-        [ "~Profile", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a0f8e8543ce925703ccc57298a9b59ffa", null ],
-        [ "getParent", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a668c3639f097e620af04af1f38f49ddd", null ],
-        [ "getName", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a853226bf49c80513c8661d9a8cd15b63", null ],
-        [ "isVertexCompressionSupported", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#ac003ed37b877d3362bbaa39661865716", null ],
-        [ "generate", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a0c47702015bcc5ad4a4920d02a67da2b", null ],
-        [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a70a4e9bf4482762227e48c061759c1d2", null ],
-        [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a5a0fe2d07ebba9d0759b28f8cf90174e", null ],
-        [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a4ab7d26991576153fe480c316ccfef86", null ],
-        [ "updateCompositeMap", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a9bb28eb51fc5229209a72564315d3eb1", null ],
-        [ "updateParams", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#a8efea3f1c4506d600d96995ba0d61164", null ],
-        [ "updateParamsForCompositeMap", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#abcb1087d4d2f5b60ba99a22a86dde5f4", null ],
-        [ "requestOptions", "class_ogre_1_1_terrain_material_generator_1_1_profile.html#ad4cbd3a430cdf5ce892ab63ef8ad270b", null ]
+      [ "Profile", "struct_ogre_1_1_terrain_material_generator_1_1_profile.html", [
+        [ "~Profile", "struct_ogre_1_1_terrain_material_generator_1_1_profile.html#a0f8e8543ce925703ccc57298a9b59ffa", null ]
       ] ],
-      [ "ProfileList", "class_ogre_1_1_terrain_material_generator.html#a2751de74a4f553835e168949e2aef522", null ],
       [ "TerrainMaterialGenerator", "class_ogre_1_1_terrain_material_generator.html#a533d059caa8ac039c9591fb47b1ea82e", null ],
       [ "~TerrainMaterialGenerator", "class_ogre_1_1_terrain_material_generator.html#a1de7023a59600699ae10003ec5005fb4", null ],
-      [ "getProfiles", "class_ogre_1_1_terrain_material_generator.html#ac435358bb3b5b492a54c0e2a0e86c5d5", null ],
-      [ "setActiveProfile", "class_ogre_1_1_terrain_material_generator.html#aaf1237c1f7b754f2c4d1d172c7690508", null ],
-      [ "setActiveProfile", "class_ogre_1_1_terrain_material_generator.html#a0580472a86a3c9cadfe6c494e5005854", null ],
-      [ "getActiveProfile", "class_ogre_1_1_terrain_material_generator.html#a52dd5cd5e5c835c3a03a4e3300d48ed5", null ],
+      [ "getActiveProfile", "class_ogre_1_1_terrain_material_generator.html#ac4b5e697dd3c1b8955e764543a625429", null ],
       [ "_markChanged", "class_ogre_1_1_terrain_material_generator.html#ae6cdf5dafc5bbea8e8241b54689798de", null ],
       [ "getChangeCount", "class_ogre_1_1_terrain_material_generator.html#a7c66198986a8b44314be2aedcfbaf4fe", null ],
-      [ "getLayerDeclaration", "class_ogre_1_1_terrain_material_generator.html#aa2ab7530d16dc3e815dd3482698197d1", null ],
-      [ "canGenerateUsingDeclaration", "class_ogre_1_1_terrain_material_generator.html#a7f9892827501c4907da1775e3c0c067b", null ],
+      [ "getLayerDeclaration", "class_ogre_1_1_terrain_material_generator.html#a865728fd9130cf62ac544f305fb5307f", null ],
       [ "isVertexCompressionSupported", "class_ogre_1_1_terrain_material_generator.html#a73368819720d8898e87497463e27f21e", null ],
       [ "requestOptions", "class_ogre_1_1_terrain_material_generator.html#af56363e3dbbffde7872cf88b869565ac", null ],
-      [ "generate", "class_ogre_1_1_terrain_material_generator.html#aa9e7fb7cee77cc1bb1d88fa6c3de7f5e", null ],
-      [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator.html#acaa6cd4b06a385638fed2603480d8445", null ],
+      [ "generate", "class_ogre_1_1_terrain_material_generator.html#a0544cc90574d539f22ccf2018818b41b", null ],
+      [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator.html#aecdc7427130af4e06ad56d7d4daefdc1", null ],
       [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator.html#a914f877ab8bb96f994160eb2b325a8cd", null ],
       [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator.html#a6402e1c3e9770043be75b845abbdc79a", null ],
-      [ "updateCompositeMap", "class_ogre_1_1_terrain_material_generator.html#aaa151085991db558a3e94748356c8156", null ],
+      [ "updateCompositeMap", "class_ogre_1_1_terrain_material_generator.html#a4316a3691b3bf6d9f0164cc33758280e", null ],
       [ "updateParams", "class_ogre_1_1_terrain_material_generator.html#aed0ac64c47fa577fab20e844b02b0aa5", null ],
       [ "updateParamsForCompositeMap", "class_ogre_1_1_terrain_material_generator.html#a15db830ec2609de8e70e90861a30b8a7", null ],
-      [ "setDebugLevel", "class_ogre_1_1_terrain_material_generator.html#acfbb5218a477deb4065d0eadd8c1f0c3", null ],
-      [ "getDebugLevel", "class_ogre_1_1_terrain_material_generator.html#ac4df6fc0a5310ac806299ebf607afe9d", null ],
-      [ "_renderCompositeMap", "class_ogre_1_1_terrain_material_generator.html#abbe57c1cdc0ff8acb1ab5e837f0aa573", null ],
+      [ "setDebugLevel", "class_ogre_1_1_terrain_material_generator.html#aa53d7e61d51cc399bdce7afb807acff0", null ],
+      [ "getDebugLevel", "class_ogre_1_1_terrain_material_generator.html#af9bef5cf6c1fe8d82675633066fc9e51", null ],
+      [ "_renderCompositeMap", "class_ogre_1_1_terrain_material_generator.html#ad407c34ad20592d0924b88efa9b89434", null ],
       [ "_getCompositeMapRTT", "class_ogre_1_1_terrain_material_generator.html#a9a644d1701f65993222a4592ad917176", null ]
     ] ],
     [ "Ogre::TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html", [
       [ "SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html", [
-        [ "SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a90df73df0e48989a8958d9ad94ad2c48", null ],
+        [ "SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aa376d18067a63f6fb9b5d531c7ce7d4c", null ],
         [ "~SM2Profile", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#af77b3b4643c1250800d7427c09d030b7", null ],
         [ "generate", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aba3b26e555ef8fbaade9546e508c647e", null ],
-        [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a12756eace5839670dc84766aa799abd1", null ],
         [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a3ce92aea13814d0bbb5d32654634e9a8", null ],
-        [ "updateParams", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a6e7d0b079cef03335718ec90d96828c8", null ],
-        [ "updateParamsForCompositeMap", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a003757f0377d6fa5f5e4028ac0ad8a91", null ],
-        [ "requestOptions", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#afca5a13d139293248c27c5e586be228c", null ],
-        [ "isVertexCompressionSupported", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aa78f4d0bebec3dcb25139ae40bfc1816", null ],
         [ "isLayerNormalMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ad1ad77bcb9bdd16acc999b17665620b6", null ],
         [ "setLayerNormalMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a53b717248396dc049de442f816b1e1fb", null ],
         [ "isLayerParallaxMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#adc3a8cfc9f04590aafbce270153b64be", null ],
         [ "setLayerParallaxMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a2f80249d865a97ceb69abff9d6333841", null ],
+        [ "setLayerParallaxOcclusionMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a60d0dfbb80efbcb427cca6c4706967e9", null ],
+        [ "isLayerOcclusionMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ae256c5404f7c67c0fdecc8d517287ded", null ],
         [ "isLayerSpecularMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ae95cfc2e78b601cb172b53741182337f", null ],
         [ "setLayerSpecularMappingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a2e61822498f7362d985a034f5226567a", null ],
-        [ "isGlobalColourMapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ac605e85633e619e909a544f69d2430e8", null ],
-        [ "setGlobalColourMapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a70a0feeeb8bf0b77c82e06bfeebb68d5", null ],
-        [ "isLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a0bf573ea46af680eabea0dcebb5135ec", null ],
-        [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aa507a0f10734cecdab43701169970016", null ],
-        [ "isCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ac8c9b5ae8e4b10bb6451896879cc95ee", null ],
-        [ "setCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aaa64157d2401e518fcbc30b15911d9b8", null ],
-        [ "getReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#adebb6b2c438f695634fc5713ef0ec3ac", null ],
-        [ "setReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a37ba62bf3961095da08a3092bb3e3378", null ],
         [ "setReceiveDynamicShadowsPSSM", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aedb34b1f7987eb59fcc39448bd9482a0", null ],
         [ "getReceiveDynamicShadowsPSSM", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ab9597d724542d8312dd95555076bfca1", null ],
-        [ "setReceiveDynamicShadowsDepth", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a4f7d6b46ec1f0112581dfe8d1c225f82", null ],
-        [ "getReceiveDynamicShadowsDepth", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ad05e8720289fa690a7eb067ddf866ed1", null ],
-        [ "setReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ac0d80ec80ca2029cdc7b53181998967e", null ],
-        [ "getReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#abdad895571b1c8eee7afb93ce3ed6568", null ],
-        [ "isShadowingEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a3ee1366c733ac203bb789983ab45c63a", null ]
+        [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aa507a0f10734cecdab43701169970016", null ],
+        [ "setCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#aaa64157d2401e518fcbc30b15911d9b8", null ],
+        [ "setReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#a37ba62bf3961095da08a3092bb3e3378", null ],
+        [ "setReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a_1_1_s_m2_profile.html#ac0d80ec80ca2029cdc7b53181998967e", null ]
       ] ],
       [ "TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html#ac41cdd05e80c7eed45f59a16e13ec740", null ],
-      [ "~TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html#af5c5973e8e5c79a9134fad7b5a4f7212", null ]
+      [ "~TerrainMaterialGeneratorA", "class_ogre_1_1_terrain_material_generator_a.html#af5c5973e8e5c79a9134fad7b5a4f7212", null ],
+      [ "getMainRenderState", "class_ogre_1_1_terrain_material_generator_a.html#a1a8e03b85c797366f2c6c9884562ab63", null ],
+      [ "setLayerNormalMappingEnabled", "class_ogre_1_1_terrain_material_generator_a.html#aa4f97a55a7ec7305c27c60f921993513", null ],
+      [ "setLayerSpecularMappingEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a0e433224bc7b1d34efd12615996806bc", null ],
+      [ "getReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a.html#adc87e62203f4c7e6cccb77b9491a5114", null ],
+      [ "setReceiveDynamicShadowsEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a199f18da0c87293bb5cb775a06471b28", null ],
+      [ "setReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a.html#ab915f3711d239b3f7d06745a8fbe536b", null ],
+      [ "getReceiveDynamicShadowsLowLod", "class_ogre_1_1_terrain_material_generator_a.html#ae5c249f3f2f884728e74b5e1681cb6f7", null ],
+      [ "isLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#ae541f5de2463055f1c9ac57c8a144b75", null ],
+      [ "setCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a0fee94d1b14e1f02cb47f567dfa1a246", null ],
+      [ "isCompositeMapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a5242d90d28b34a6c0b661b5702d2fdc7", null ],
+      [ "getActiveProfile", "class_ogre_1_1_terrain_material_generator_a.html#a3151937a7eebd65f64002666ccd38d54", null ],
+      [ "isVertexCompressionSupported", "class_ogre_1_1_terrain_material_generator_a.html#a53e943ef541981b795a3634ad32518ca", null ],
+      [ "requestOptions", "class_ogre_1_1_terrain_material_generator_a.html#acddcb6b0c7158082b8e343693110e6cc", null ],
+      [ "generate", "class_ogre_1_1_terrain_material_generator_a.html#a2d981ec289239a99c9c7b73775ee18fa", null ],
+      [ "generateForCompositeMap", "class_ogre_1_1_terrain_material_generator_a.html#a00024c995a93cb5f144c74c13c77f681", null ],
+      [ "setLightmapEnabled", "class_ogre_1_1_terrain_material_generator_a.html#a6c10400f3549cfa8727fd1cc88cc2d5b", null ],
+      [ "getMaxLayers", "class_ogre_1_1_terrain_material_generator_a.html#a80e17a839bcf6380b55f98b10a76699f", null ],
+      [ "updateParams", "class_ogre_1_1_terrain_material_generator_a.html#a0767a5802f8f14ea6d0caba6ce45d414", null ],
+      [ "updateParamsForCompositeMap", "class_ogre_1_1_terrain_material_generator_a.html#ad1f0ee06a094751cdf130503fda1ad17", null ]
     ] ],
     [ "Ogre::TerrainPagedWorldSection", "class_ogre_1_1_terrain_paged_world_section.html", [
       [ "TerrainDefiner", "class_ogre_1_1_terrain_paged_world_section_1_1_terrain_definer.html", [
@@ -618,12 +574,9 @@ var group___terrain =
       [ "getGridStrategyData", "class_ogre_1_1_terrain_paged_world_section.html#aff3ffe2df67866bfab9a5f054ab1609e", null ],
       [ "setLoadingIntervalMs", "class_ogre_1_1_terrain_paged_world_section.html#a9d208b0b43ad3838f95f9a3309c8ecba", null ],
       [ "getLoadingIntervalMs", "class_ogre_1_1_terrain_paged_world_section.html#a85a4fdb8bec2f5a7f2a13694e2400209", null ],
-      [ "loadPage", "class_ogre_1_1_terrain_paged_world_section.html#a1757d16ae402efa4553fec18d44edda0", null ],
-      [ "unloadPage", "class_ogre_1_1_terrain_paged_world_section.html#a11bef4778399774ee5e32480f6b2bb69", null ],
-      [ "handleRequest", "class_ogre_1_1_terrain_paged_world_section.html#a436586b9e99868d690d76971562fd4ed", null ],
-      [ "handleResponse", "class_ogre_1_1_terrain_paged_world_section.html#a0d87c6c1fa81abdda4ee6925bfa10e49", null ],
-      [ "setDefiner", "class_ogre_1_1_terrain_paged_world_section.html#ad1ec44d3c798917114aa713a8281edf2", null ],
-      [ "WORKQUEUE_LOAD_TERRAIN_PAGE_REQUEST", "class_ogre_1_1_terrain_paged_world_section.html#a103d6fc3c2af27e6cbd9dc5c948fb25d", null ]
+      [ "loadPage", "class_ogre_1_1_terrain_paged_world_section.html#a1a65128a0c2d3c56426c36a5e735428d", null ],
+      [ "unloadPage", "class_ogre_1_1_terrain_paged_world_section.html#a0d84fb8359d1d53826db2c4eea8642ce", null ],
+      [ "setDefiner", "class_ogre_1_1_terrain_paged_world_section.html#ad1ec44d3c798917114aa713a8281edf2", null ]
     ] ],
     [ "Ogre::TerrainPaging", "class_ogre_1_1_terrain_paging.html", [
       [ "TerrainPaging", "class_ogre_1_1_terrain_paging.html#a9626171913fa5a7a0750d1c7fde899be", null ],
@@ -640,7 +593,7 @@ var group___terrain =
         [ "lastTransitionDist", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#ac82a3ddf378272493d9d82100c17597a", null ],
         [ "lastCFactor", "struct_ogre_1_1_terrain_quad_tree_node_1_1_lod_level.html#afd5d89ee1eaff154e44347c15af2fba3", null ]
       ] ],
-      [ "LodLevelList", "class_ogre_1_1_terrain_quad_tree_node.html#aae9eb87fc6a1843c06184ef091b12d69", null ],
+      [ "LodLevelList", "class_ogre_1_1_terrain_quad_tree_node.html#ab2c83f326edecd38e6baa64a67521f9e", null ],
       [ "TerrainQuadTreeNode", "class_ogre_1_1_terrain_quad_tree_node.html#a6e8a302845886dc29bd29491f4e17111", null ],
       [ "~TerrainQuadTreeNode", "class_ogre_1_1_terrain_quad_tree_node.html#a525a7166daaa69292b2350de66784f58", null ],
       [ "getXOffset", "class_ogre_1_1_terrain_quad_tree_node.html#a21057fc9dca730125457d9fb0e7d4588", null ],
@@ -673,8 +626,8 @@ var group___terrain =
       [ "rectIntersectsNode", "class_ogre_1_1_terrain_quad_tree_node.html#af27dbb3371e5c51772e304eef37afb3f", null ],
       [ "rectContainsNode", "class_ogre_1_1_terrain_quad_tree_node.html#ab89d0817244bb68ab25500eec8c360c2", null ],
       [ "pointIntersectsNode", "class_ogre_1_1_terrain_quad_tree_node.html#a67493d0f5329e958ea9747e30b32fa55", null ],
-      [ "getBoundingBox", "class_ogre_1_1_terrain_quad_tree_node.html#a86e695eb5045403fc28f0c0d5533d696", null ],
-      [ "getBoundingRadius", "class_ogre_1_1_terrain_quad_tree_node.html#afb34be129bba773c740ed737f5632950", null ],
+      [ "getBoundingBox", "class_ogre_1_1_terrain_quad_tree_node.html#a390b02c9923941792b4f9870f61be02d", null ],
+      [ "getBoundingRadius", "class_ogre_1_1_terrain_quad_tree_node.html#acd935c7ebebe4e9b2f5cf0b8695db60a", null ],
       [ "getLocalCentre", "class_ogre_1_1_terrain_quad_tree_node.html#a4b0024e42e7eff99a65abf0c81a9939c", null ],
       [ "getMinHeight", "class_ogre_1_1_terrain_quad_tree_node.html#a8c7eb959dae089d763e027ef3e459abd", null ],
       [ "getMaxHeight", "class_ogre_1_1_terrain_quad_tree_node.html#a1a2433c6e02f4434a43be08c6c1b9fc9", null ],
@@ -689,22 +642,10 @@ var group___terrain =
       [ "DELTA_BUFFER", "class_ogre_1_1_terrain_quad_tree_node.html#a570b17be150e8de773197f801a6a2a2e", null ]
     ] ],
     [ "Ogre::TerrainLayerBlendMapList", "group___terrain.html#ga13ef117fcdcdaf0c609c62f297d94c16", null ],
-    [ "Ogre::TerrainLayerSamplerElementList", "group___terrain.html#gab3e9ec2172cfcad003ca034009369271", null ],
-    [ "Ogre::TerrainLayerSamplerList", "group___terrain.html#ga8bc95785d736a01b4140f9a427e9b630", null ],
+    [ "Ogre::TerrainLayerDeclaration", "group___terrain.html#ga97753876a164dbf20e586aa37750816c", null ],
     [ "Ogre::TerrainMaterialGeneratorPtr", "group___terrain.html#ga152d33cadca984511f2c0459562c7b0b", null ],
     [ "Ogre::TerrainAutoUpdateLodStrategy", "group___terrain.html#ga4e7b31c45dc1afba816f7d9bc71a301b", [
       [ "Ogre::NONE", "group___terrain.html#gga4e7b31c45dc1afba816f7d9bc71a301baf4ad13488a8b22a4309fdd0a7fb70db8", null ],
       [ "Ogre::BY_DISTANCE", "group___terrain.html#gga4e7b31c45dc1afba816f7d9bc71a301ba8b40189aba8887f4cdb96d967cd80460", null ]
-    ] ],
-    [ "Ogre::TerrainLayerSamplerSemantic", "group___terrain.html#gad6e8e88c8f2109b45648fd6f3ec00a84", [
-      [ "Ogre::TLSS_ALBEDO", "group___terrain.html#ggad6e8e88c8f2109b45648fd6f3ec00a84a6407050de320fbf7c06c77bb97e647e7", null ],
-      [ "Ogre::TLSS_NORMAL", "group___terrain.html#ggad6e8e88c8f2109b45648fd6f3ec00a84ae90f168a77e4047af27e14ca52d8205a", null ],
-      [ "Ogre::TLSS_HEIGHT", "group___terrain.html#ggad6e8e88c8f2109b45648fd6f3ec00a84adeb418649d89cf961e3f60b009a5e5fb", null ],
-      [ "Ogre::TLSS_SPECULAR", "group___terrain.html#ggad6e8e88c8f2109b45648fd6f3ec00a84ae7b29f10d891aac2a3e41c71f7fa96c7", null ]
-    ] ],
-    [ "Ogre::TechniqueType", "group___terrain.html#ga632903bb3f8ee3d838b17177bfb7cbcc", [
-      [ "Ogre::HIGH_LOD", "group___terrain.html#gga632903bb3f8ee3d838b17177bfb7cbcca5b8d4b96e0e0882f2bbcfebc98cf393d", null ],
-      [ "Ogre::LOW_LOD", "group___terrain.html#gga632903bb3f8ee3d838b17177bfb7cbcca4a929fbb87f8f18c5d46dc10fb9e73c3", null ],
-      [ "Ogre::RENDER_COMPOSITE_MAP", "group___terrain.html#gga632903bb3f8ee3d838b17177bfb7cbcca654c39dbe72fc28d943bfa476b54867d", null ]
     ] ]
 ];
\ No newline at end of file
