@@ -5,15 +5,14 @@ var indexSectionsWithContent =
   2: "aops",
   3: "abdehimnoprstv",
   4: "_abcdefghiklmnopqrstuvwxyz~",
-  5: "_abcdefghiklmnopqrstuvwxyz",
+  5: "_abcdefghiklmnoprstuvwxyz",
   6: "_abcdefghiklmnopqrstuvwz",
   7: "abcdefghilmnopqrstuvw",
   8: "_abcdefghijklmnopqrstuvwz",
-  9: "cdlnps",
-  10: "ago",
-  11: "_abcdeghmnorsvw",
-  12: "abcdefgilmoprstv",
-  13: "abcdefghilmnoprstuvwy"
+  9: "ago",
+  10: "_bcdgmos",
+  11: "abcdefgilmoprstv",
+  12: "abcdefghilmnoprstuvwy"
 };
 
 var indexSectionNames =
@@ -27,11 +26,10 @@ var indexSectionNames =
   6: "typedefs",
   7: "enums",
   8: "enumvalues",
-  9: "properties",
-  10: "related",
-  11: "defines",
-  12: "groups",
-  13: "pages"
+  9: "related",
+  10: "defines",
+  11: "groups",
+  12: "pages"
 };
 
 var indexSectionLabels =
@@ -45,10 +43,9 @@ var indexSectionLabels =
   6: "Typedefs",
   7: "Enumerations",
   8: "Enumerator",
-  9: "Properties",
-  10: "Friends",
-  11: "Macros",
-  12: "Modules",
-  13: "Pages"
+  9: "Friends",
+  10: "Macros",
+  11: "Modules",
+  12: "Pages"
 };
 
